==> chrome-devtools-kotlin-0.6.1-sources.jar: org/hildan/chrome/devtools/domains/deviceorientation/DeviceOrientationDomain.kt <==
package org.hildan.chrome.devtools.domains.deviceorientation

import kotlin.Double
import kotlin.Unit
import kotlinx.serialization.Serializable
import org.hildan.chrome.devtools.protocol.ChromeDPSession
import org.hildan.chrome.devtools.protocol.ExperimentalChromeApi

/**
 * Request object containing input parameters for the
 * [DeviceOrientationDomain.setDeviceOrientationOverride] command.
 */
@Serializable
public data class SetDeviceOrientationOverrideRequest(
  /**
   * Mock alpha
   */
  public val alpha: Double,
  /**
   * Mock beta
   */
  public val beta: Double,
  /**
   * Mock gamma
   */
  public val gamma: Double
)

/**
 *
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/DeviceOrientation)
 */
@ExperimentalChromeApi
public class DeviceOrientationDomain internal constructor(
  private val session: ChromeDPSession
) {
  /**
   * Clears the overridden Device Orientation.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/DeviceOrientation/#method-clearDeviceOrientationOverride)
   */
  public suspend fun clearDeviceOrientationOverride(): Unit =
      session.request("DeviceOrientation.clearDeviceOrientationOverride", Unit)

  /**
   * Overrides the Device Orientation.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/DeviceOrientation/#method-setDeviceOrientationOverride)
   */
  public suspend fun setDeviceOrientationOverride(input: SetDeviceOrientationOverrideRequest): Unit
      = session.request("DeviceOrientation.setDeviceOrientationOverride", input)
}

==> chrome-devtools-kotlin-0.13.1-sources.jar: org/hildan/chrome/devtools/domains/deviceorientation/DeviceOrientationDomain.kt <==
@file:Suppress("RedundantVisibilityModifier", "DEPRECATION", "EXPERIMENTAL_API_USAGE")

package org.hildan.chrome.devtools.domains.deviceorientation

import kotlin.Double
import kotlin.Suppress
import kotlin.Unit
import kotlinx.serialization.Serializable
import org.hildan.chrome.devtools.protocol.ChromeDPSession
import org.hildan.chrome.devtools.protocol.ExperimentalChromeApi

/**
 * Request object containing input parameters for the
 * [DeviceOrientationDomain.setDeviceOrientationOverride] command.
 */
@Serializable
public data class SetDeviceOrientationOverrideRequest(
  /**
   * Mock alpha
   */
  public val alpha: Double,
  /**
   * Mock beta
   */
  public val beta: Double,
  /**
   * Mock gamma
   */
  public val gamma: Double
)

/**
 *
 *
 * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/DeviceOrientation)
 */
@ExperimentalChromeApi
public class DeviceOrientationDomain internal constructor(
  private val session: ChromeDPSession
) {
  /**
   * Clears the overridden Device Orientation.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/DeviceOrientation/#method-clearDeviceOrientationOverride)
   */
  public suspend fun clearDeviceOrientationOverride(): Unit =
      session.request("DeviceOrientation.clearDeviceOrientationOverride", Unit)

  /**
   * Overrides the Device Orientation.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/DeviceOrientation/#method-setDeviceOrientationOverride)
   */
  public suspend fun setDeviceOrientationOverride(input: SetDeviceOrientationOverrideRequest): Unit
      = session.request("DeviceOrientation.setDeviceOrientationOverride", input)
}
